from flask import Flask
from pymongo import MongoClient
from flask_jwt_extended import JWTManager

from config import Config
from singletons.database_singleton import DatabaseSingleton

from controllers.user_controller import user_blueprint
from controllers.reservation_controller import reservation_blueprint

app = Flask(__name__)
app.config['JWT_SECRET_KEY'] = Config.JWT_SECRET_KEY

app.register_blueprint(user_blueprint, url_prefix='/user')
app.register_blueprint(reservation_blueprint, url_prefix='/reservation')

jwt = JWTManager(app)
client = MongoClient(Config.MONGO_URI)
db = DatabaseSingleton.get_instance()

if db is not None:
    print('Connected to MongoDB')
else:
    print('Failed to connect to MongoDB')

if __name__ == '__main__':
    app.run(debug=True)
