import json
from bson import ObjectId, json_util

from singletons.database_singleton import DatabaseSingleton

class ReservationRepository:
    db = DatabaseSingleton.get_instance()

    @classmethod
    def insert(cls, reservation):
        return str(cls.db.reservation.insert_one(reservation.dict()).inserted_id)

    @classmethod
    def delete(cls, reservation_id):
        try:
            result = cls.db.reservation.delete_one({"_id": ObjectId(reservation_id)})
            return result
        except:
            return None

    @classmethod
    def update(cls, reservation_id, data):
        try:
            result = cls.db.reservation.update_one({"_id": ObjectId(reservation_id)}, {"$set": data})
            return result
        except:
            return None

    @classmethod
    def get_by_id(cls, reservation_id):
        return list(cls.db.reservation.find({"_id": ObjectId(reservation_id)}))

    @classmethod
    def list_all(cls, filters=None):
        query = {}
        if filters:
            if "date" in filters:
                query["date"] = {"$gte": filters["date"]}
            if "room_id" in filters:
                query["room_id"] = filters["room_id"]

        results = cls.db.reservation.find(query)

        reservations = []
        for res in results:
            res["id"] = str(res["_id"])
            del res["_id"]
            reservations.append(res)
        
        return reservations